@@ -18,6 +18,12 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
+import gettext
+
+gettext.install("ibus-libzhuyin")
 
 def get_version():
-    return "1.8.2"
+    return "1.9.0"
+
+def get_longname():
+    return _("New Zhuyin")
