@@ -161,9 +161,12 @@ PhoneticEditor::processSpace (guint keyval, guint keycode,
             return TRUE;
         }
 
+#if 0
         if (!m_config.spaceShowCandidates ()) {
             return insert (keyval, keycode, modifiers);
         }
+#endif
+        return FALSE;
     }
 
     if (STATE_CANDIDATE_SHOWN == m_input_state ||
@@ -410,6 +413,7 @@ PhoneticEditor::processEasySymbolKey (guint keyval, guint keycode,
     insert_symbol (m_text, m_cursor++, BUILTIN_SYMBOL_TYPE,
                    lookup, symbol);
 
+    updateZhuyin ();
     update ();
     return TRUE;
 }
@@ -612,6 +616,7 @@ PhoneticEditor::selectCandidate (guint index)
         m_cursor += offset;
         m_input_state = STATE_INPUT;
 
+        updateZhuyin ();
         update ();
         return TRUE;
     }
@@ -633,13 +638,14 @@ PhoneticEditor::selectCandidate (guint index)
                 lookup = (gchar) ch;
 
             assert (BUILTIN_SYMBOL_TYPE == symbols->getType ());
-            erase_input_sequence (m_text, m_cursor, 1);
+            /* for user symbol, only need to insert symbol. */
             insert_symbol (m_text, m_cursor, symbols->getType (),
                            lookup, choice);
 
             m_cursor += offset;
             m_input_state = STATE_INPUT;
 
+            updateZhuyin ();
             update ();
             return TRUE;
         }
@@ -942,8 +948,9 @@ PhoneticEditor::insertSymbol (guint keyval)
     if (is_full_width_symbol (keyval)) {
 
         if (is_special_symbol (keyval)) {
-            String choice;
-            assert (convert_special_symbol (keyval, choice));
+            String choice = keyval;
+            if (m_props.modeFullWidth ())
+                assert (convert_special_symbol (keyval, choice));
 
             String lookup;
             int ch = find_lookup_key (choice);
